==> refcodes-graphical-3.2.6-sources.jar: org/refcodes/graphical/RgbPixelImpl.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.graphical;

import java.awt.Color;

/**
 * The Class RgbPixelImpl.
 *
 * @author steiner
 */
public class RgbPixelImpl extends RgbColorImpl implements RgbPixel {

	// /////////////////////////////////////////////////////////////////////////
	// STATICS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTANTS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * {@inheritDoc}
	 */
	public RgbPixelImpl() {
	}

	/**
	 * {@inheritDoc}
	 */
	public RgbPixelImpl( Color aAwtColor ) {
		super( aAwtColor );
	}

	/**
	 * {@inheritDoc}
	 */
	public RgbPixelImpl( int aAlphaPortion, int aRedPortion, int aGreenPortion, int aBluePortion ) {
		super( aAlphaPortion, aRedPortion, aGreenPortion, aBluePortion );
	}

	/**
	 * {@inheritDoc}
	 */
	public RgbPixelImpl( int aRgbValue ) {
		super( aRgbValue );
	}

	// /////////////////////////////////////////////////////////////////////////
	// INJECTION:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HOOKS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HELPER:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// INNER CLASSES:
	// /////////////////////////////////////////////////////////////////////////

}

==> refcodes-graphical-3.2.7-sources.jar: org/refcodes/graphical/RgbPixelImpl.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.graphical;

import java.awt.Color;

/**
 * The Class RgbPixelImpl.
 *
 * @author steiner
 */
public class RgbPixelImpl extends RgbColorImpl implements RgbPixel {

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * {@inheritDoc}
	 */
	public RgbPixelImpl() {}

	/**
	 * {@inheritDoc}
	 */
	public RgbPixelImpl( Color aAwtColor ) {
		super( aAwtColor );
	}

	/**
	 * {@inheritDoc}
	 */
	public RgbPixelImpl( int aAlphaPortion, int aRedPortion, int aGreenPortion, int aBluePortion ) {
		super( aAlphaPortion, aRedPortion, aGreenPortion, aBluePortion );
	}

	/**
	 * {@inheritDoc}
	 */
	public RgbPixelImpl( int aRgbValue ) {
		super( aRgbValue );
	}
}
